summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorwtc <devnull@localhost>1998-04-29 00:08:32 +0000
committerwtc <devnull@localhost>1998-04-29 00:08:32 +0000
commit1e332bf7c01e73848e01b7dc81a40efb2553afba (patch)
tree4e672e3efb5ddf92a96b73353af774f584d87e22
parentd32f0e7e8878fee0d211e85e33886ef86b963144 (diff)
downloadnspr-hg-1e332bf7c01e73848e01b7dc81a40efb2553afba.tar.gz
ReliantUNIX is renamed SINIX.OJI_19980430_BASE
-rw-r--r--lib/msgc/tests/Makefile2
-rw-r--r--pr/include/md/Makefile2
-rw-r--r--pr/include/md/_reliantunix.h4
-rw-r--r--pr/src/md/unix/Makefile6
-rw-r--r--pr/src/md/unix/objs.mk6
-rw-r--r--pr/src/md/unix/reliantunix.c8
-rw-r--r--pr/tests/Makefile2
7 files changed, 15 insertions, 15 deletions
diff --git a/lib/msgc/tests/Makefile b/lib/msgc/tests/Makefile
index 3c02cca4..73fc9c81 100644
--- a/lib/msgc/tests/Makefile
+++ b/lib/msgc/tests/Makefile
@@ -191,7 +191,7 @@ EXTRA_LIBS = -lsocket
export LD_RUN_PATH = $(PWD)/$(DIST)/lib
endif
-ifeq ($(OS_ARCH),ReliantUNIX)
+ifeq ($(OS_ARCH),SINIX)
EXTRA_LIBS = -lsocket -lnsl -lgen -ldl -lresolv /usr/ucblib/libucb.a
# This hardcodes in the executable programs the directory to find
# libnspr.so etc. at program startup. Equivalent to the -R or -rpath
diff --git a/pr/include/md/Makefile b/pr/include/md/Makefile
index 9d62722d..589aa855 100644
--- a/pr/include/md/Makefile
+++ b/pr/include/md/Makefile
@@ -75,7 +75,7 @@ MDCPUCFG_H = _solaris.cfg
endif
endif
-ifeq ($(OS_ARCH),ReliantUNIX)
+ifeq ($(OS_ARCH),SINIX)
MDCPUCFG_H = _reliantunix.cfg
endif
diff --git a/pr/include/md/_reliantunix.h b/pr/include/md/_reliantunix.h
index b64d93fd..d7afb63d 100644
--- a/pr/include/md/_reliantunix.h
+++ b/pr/include/md/_reliantunix.h
@@ -28,8 +28,8 @@
* Internal configuration macros
*/
-#define PR_LINKER_ARCH "reliantunix"
-#define _PR_SI_SYSNAME "ReliantUNIX"
+#define PR_LINKER_ARCH "sinix"
+#define _PR_SI_SYSNAME "SINIX"
#define _PR_SI_ARCHITECTURE "mips"
#define PR_DLL_SUFFIX ".so"
diff --git a/pr/src/md/unix/Makefile b/pr/src/md/unix/Makefile
index 16a5e52b..e5fb34e5 100644
--- a/pr/src/md/unix/Makefile
+++ b/pr/src/md/unix/Makefile
@@ -134,7 +134,7 @@ endif
ifeq ($(OS_ARCH),UNIXWARE)
CSRCS += $(UNIXWARE_CSRCS)
endif
-ifeq ($(OS_ARCH),ReliantUNIX)
+ifeq ($(OS_ARCH),SINIX)
CSRCS += $(RELIANTUNIX_CSRCS)
endif
ifeq ($(OS_ARCH),NEC)
@@ -170,8 +170,8 @@ ifeq ($(OS_ARCH),SunOS)
endif
endif
-ifeq ($(OS_ARCH), ReliantUNIX)
- ASFILES = os_$(OS_ARCH).s
+ifeq ($(OS_ARCH), SINIX)
+ ASFILES = os_ReliantUNIX.s
endif
ifeq ($(OS_ARCH)$(OS_RELEASE),BSD_OS2.1)
diff --git a/pr/src/md/unix/objs.mk b/pr/src/md/unix/objs.mk
index 1a3b9035..abb77d73 100644
--- a/pr/src/md/unix/objs.mk
+++ b/pr/src/md/unix/objs.mk
@@ -127,7 +127,7 @@ endif
ifeq ($(OS_ARCH),UNIXWARE)
CSRCS += $(UNIXWARE_CSRCS)
endif
-ifeq ($(OS_ARCH),ReliantUNIX)
+ifeq ($(OS_ARCH),SINIX)
CSRCS += $(RELIANTUNIX_CSRCS)
endif
ifeq ($(OS_ARCH),NEC)
@@ -163,8 +163,8 @@ ifeq ($(OS_ARCH),SunOS)
endif
endif
-ifeq ($(OS_ARCH), ReliantUNIX)
- ASFILES = os_$(OS_ARCH).s
+ifeq ($(OS_ARCH), SINIX)
+ ASFILES = os_ReliantUNIX.s
endif
ifeq ($(OS_ARCH)$(OS_RELEASE),BSD_OS2.1)
diff --git a/pr/tests/Makefile b/pr/tests/Makefile
index 296e5567..1ca516b7 100644
--- a/pr/tests/Makefile
+++ b/pr/tests/Makefile
@@ -279,7 +279,7 @@ EXTRA_LIBS = -lsocket
export LD_RUN_PATH = $(PWD)/$(DIST)/lib
endif
-ifeq ($(OS_ARCH),ReliantUNIX)
+ifeq ($(OS_ARCH),SINIX)
EXTRA_LIBS = -lsocket -lnsl -lgen -ldl -lresolv /usr/ucblib/libucb.a
# This hardcodes in the executable programs the directory to find
# libnspr.so etc. at program startup. Equivalent to the -R or -rpath
diff --git a/pr/src/md/unix/reliantunix.c b/pr/src/md/unix/reliantunix.c
index 755d7f8c..0bd597d6 100644
--- a/pr/src/md/unix/reliantunix.c
+++ b/pr/src/md/unix/reliantunix.c
@@ -17,7 +17,7 @@
*/
/*
* ReliantUNIX5.4 - copied from unixware.c by chrisk 040497
*/
#include "primpl.h"
@@ -89,12 +89,12 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
/* These functions should not be called for ReliantUNIX */
/* Why? Just copied it from UNIXWARE... flying-by-night, chrisk 040497 */
void
_MD_YIELD(void)
{
- PR_NOT_REACHED("_MD_YIELD should not be called for ReliantUNIX.");
+ PR_NOT_REACHED("_MD_YIELD should not be called for SINIX.");
}
PRStatus
@@ -106,7 +106,7 @@ _MD_CREATE_THREAD(
PRThreadState state,
PRUint32 stackSize)
{
- PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for ReliantUNIX.");
+ PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for SINIX.");
#if defined(SNI) && !defined(__GNUC__)
/* make compiler happy */
return (PRStatus)NULL;
@@ -17,7 +17,7 @@
*/
/*
- * ReliantUNIX5.4 - copied from unixware.c by chrisk 040497
+ * SINIX (ReliantUNIX) 5.4 - copied from unixware.c by chrisk 040497
*/
#include "primpl.h"
@@ -89,12 +89,12 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
-/* These functions should not be called for ReliantUNIX */
+/* These functions should not be called for SINIX */
/* Why? Just copied it from UNIXWARE... flying-by-night, chrisk 040497 */
void